![](https://img.shields.io/pypi/v/demo-multiply)
![](https://img.shields.io/pypi/wheel/demo-multiply)
![](https://img.shields.io/pypi/pyversions/demo-multiply)
![](https://img.shields.io/pypi/implementation/demo-multiply)
![](https://img.shields.io/pypi/l/demo-multiply)
![](https://img.shields.io/github/repo-size/saeedanabtawi/demo-multiply)
![](https://img.shields.io/github/directory-file-count/saeedanabtawi/demo-multiply)
![](https://img.shields.io/github/languages/code-size/saeedanabtawi/demo-multiply)
![](https://img.shields.io/github/discussions/saeedanabtawi/demo-multiply)
![](https://img.shields.io/github/actions/workflow/status/saeedanabtawi/demo-multiply/workflow.yml)


# Demo multiply
A small demo library.

### Installation
```
pip install demo-multiply
```

### Get started
How to multiply one number by another with this lib:

```Python
from demo_multiply import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```
